@@ -19,7 +19,7 @@ from plotnine import *
 import matplotlib.pyplot as plt
 from scipy.stats import hypergeom
 from collections import defaultdict
-from enrRiceTrait.PTE_config import db_config
+# from enrRiceTrait.src.enrRiceTrait.PTE_config import db_config
 
 # todo: conver all "concept" and "term" to "trait"
 # todo: Enricher initialize
@@ -131,8 +131,8 @@ class Gene_Ontology_enrichment:
         self.enrich_dataframe = ''
 
         # self.db_check()
-        self.load_ontology()
-        self.load_background_data()
+        # self.load_ontology()
+        # self.load_background_data()
 
     # todo: ftp for data download.
     @staticmethod
@@ -147,12 +147,12 @@ class Gene_Ontology_enrichment:
             print('Downloading: {0} for package.'.format(os.path.basename(db_config['ontology_file'])))
             url = db_config['ontology_url']
             file_name = wget.download(url, out=db_config['ontology_file'])
-            print(file_name)
+            # print(file_name)
         if not os.path.exists(db_config['PT_anno_file']):
             print('Downloading: {0} for package.'.format(db_config['PT_anno_file']))
             url = db_config['PT_anno_url']
             file_name = wget.download(url, out=db_config['PT_anno_file'])
-            print(file_name)
+            # print(file_name)
 
     # todo: ontology class
     #       parent, child or other.
@@ -295,7 +295,7 @@ class Gene_Ontology_enrichment:
             if p_value < self.p_threshold:
                 self.enrich_result.terms_p_value[trait_id] = p_value
                 # fixme: check here.
-                print(trait_id, x, k)
+                # print(trait_id, x, k)
                 self.enrich_result.Gene_Ratio[trait_id] =  x / k
                 self.enrich_result.BG_Ratio[trait_id] = k / N
 
@@ -348,11 +348,11 @@ class Gene_Ontology_enrichment:
                                          'Count': trait_count
                                          })
 
-        self.enrich_dataframe[ 'ID_Name' ] = data[ 'ID' ] + ' ' + data[ 'Name' ]
+        self.enrich_dataframe[ 'ID_Name' ] = self.enrich_dataframe[ 'ID' ] + ' ' + self.enrich_dataframe[ 'Name' ]
 
-        self.enrich_dataframe[ 'p_value_str' ] = 'p-Value ' + data[ 'p-value' ].map('{:.3e}'.format)
+        self.enrich_dataframe[ 'p_value_str' ] = 'p-Value ' + self.enrich_dataframe[ 'p-value' ].map('{:.3e}'.format)
 
-        self.enrich_dataframe[ 'neg_log_p_value' ] = -data[ 'p-value' ].map(np.log)
+        self.enrich_dataframe[ 'neg_log_p_value' ] = -self.enrich_dataframe[ 'p-value' ].map(np.log)
 
         rows, _ = self.enrich_dataframe.shape
         highest_neg_log_p_value_label = list(self.enrich_dataframe['ID'][0:5])
@@ -465,7 +465,7 @@ class Gene_Ontology_enrichment:
 
     def draw_bar_new(self, save_path='../result',  prefix='EnrRiceTrait', save_plot=False):
 
-        self.enrich_dataframe = data.sort_values(by='p-value')
+        self.enrich_dataframe = self.enrich_dataframe.sort_values(by='p-value')
 
         p1 = (ggplot( self.enrich_dataframe) +
               geom_col(aes(x='ID_Name', y='Count', color='p-value', fill='p-value')) +
@@ -494,7 +494,7 @@ class Gene_Ontology_enrichment:
 
     def draw_bubble_new(self, save_path='../result',  prefix='EnrRiceTrait', save_plot=False):
 
-        self.enrich_dataframe = data.sort_values(by='p-value')
+        self.enrich_dataframe = self.enrich_dataframe.sort_values(by='p-value')
 
         # fixme: shape='Class'
         p2 = (ggplot(self.enrich_dataframe) +
@@ -516,3 +516,23 @@ class Gene_Ontology_enrichment:
 
         return p2
 
+
+    # def draw_bubble_new_2(self, save_path='../result',  prefix='EnrRiceTrait', save_plot=False):
+    #
+    #     # fixme: color: class
+    #     # fixme: z-score
+    #     p3 = (ggplot(self.enrich_dataframe) +
+    #           geom_point(aes(
+    #               x='z-score', y='neg_log_p_value',
+    #               size='Count', color='Class', fill='Class')) +
+    #           geom_text(aes(
+    #               x='z-score', y='neg_log_p_value',
+    #               size=12, label='highest_neg_log_p_value_label')) +
+    #           xlab('Z-Score') + ylab('Negative Log P-Value') +
+    #           xlim(-3, 7) +
+    #           scale_color_cmap_d(name='Accent') +
+    #           scale_fill_cmap_d(name='Accent') +
+    #           ggtitle('Babble Plot')
+    #           )
+
+
